@@ -32,6 +32,9 @@ def main ():
     parser.add_option('-D', '--depth', metavar='LEVELS',
                 dest='FOLDER_DEPTH', type='int',
                 help='folder depth search for opening files [4]')
+    parser.add_option('-r', '--readonly', 
+                dest='READ_ONLY', action='store_true',
+                help='Remove options to save tmap files')
 
     (opts, args) = parser.parse_args()
     # Load config file if specified
