@@ -9,7 +9,7 @@
  * @version projectUtils 2.0
  * @classdesc The root namespace for projectUtils.
  */
- projectUtils = {
+var projectUtils = {
      _activeState:{},
      _hideCSVImport: false,
      _settings:[
@@ -45,7 +45,7 @@
  projectUtils.saveProject = function(urlProject) {
     interfaceUtils.prompt("Save project under the name:","NewProject")
     .then((filename) => {
-        state = projectUtils.getActiveProject();
+        var state = projectUtils.getActiveProject();
         state.filename = filename;
 
         var dataStr = "data:text/json;charset=utf-8," + encodeURIComponent(JSON.stringify(state, null, 4));
@@ -346,7 +346,8 @@ projectUtils.loadProjectFileFromServer = function(path) {
             if (tab.visible === false) {document.getElementById("title-tab-" + tab.name).style.display="none"}
         });
     }*/
-    if (state.regions) {
+    console.log("state.regions, state.regions != {}", state.regions, state.regions != {})
+    if (state.regions && Object.keys(state.regions).length > 0) {
         regionUtils.JSONValToRegions(state.regions);
     }
     if (state.regionFile) {
@@ -428,6 +429,11 @@ projectUtils.loadProjectFileFromServer = function(path) {
     if (state.hideTabs) {
         document.getElementById("level-1-tabs").classList.add("d-none");
     }
+    if (state.menuButtons) {
+        state.menuButtons.forEach(function(menuButton, i) {
+            interfaceUtils.addMenuItem([menuButton.text], function(){ window.open(menuButton.url, '_self').focus();});
+        });
+    }
     /*if (projectUtils._hideCSVImport) {
         document.getElementById("ISS_data_panel").style.display="none";
     }*/
@@ -499,8 +505,8 @@ projectUtils.convertOldMarkerFile = function(markerFile) {
         markerFile.expectedRadios.cb_gr_rand = false;
         markerFile.expectedRadios.cb_gr_key = true;
         for (setting of markerFile.settings) {
-            if (setting.module == "glUtils" && setting.function == "_globalMarkerScale")
-                markerFile.expectedHeader.scale_factor = setting.value;
+            //if (setting.module == "glUtils" && setting.function == "_globalMarkerScale")
+            //    markerFile.expectedHeader.scale_factor = setting.value;
             if (setting.module == "markerUtils" && setting.function == "_selectedShape"){
                 dictSymbol = {6:6}
                 if (dictSymbol[setting.value]) setting.value = dictSymbol[setting.value];
@@ -519,6 +525,13 @@ projectUtils.convertOldMarkerFile = function(markerFile) {
                 markerFile.expectedRadios.cb_gr_dict = true;
                 markerFile.expectedHeader.cb_gr_dict = JSON.stringify(setting.value);
             }
+            if (setting.module == "HTMLElementUtils" && setting.function == "_colorsperiter") {
+                markerFile.expectedRadios.cb_gr = true;
+                markerFile.expectedRadios.cb_gr_rand = false;
+                markerFile.expectedRadios.cb_gr_key = false;
+                markerFile.expectedRadios.cb_gr_dict = true;
+                markerFile.expectedHeader.cb_gr_dict = JSON.stringify(setting.value);
+            }
             if (setting.module == "glUtils" && setting.function == "_markerOpacity")
                 markerFile.expectedHeader.opacity = setting.value;
             if (setting.module == "HTMLElementUtils" && setting.function == "_colorsperbarcode") {
@@ -558,4 +571,46 @@ projectUtils.commonPath = function(strs) {
     }
     prefix = prefix.substring(0, prefix.lastIndexOf('/')+1);
     return prefix
+}
+
+/** Applying settings */
+projectUtils.applySettings = function (settings) {
+    if (settings) {
+        settings.forEach(function(setting, i) {
+            if (window[setting.module]) {
+                if (typeof window[setting.module][setting.function]  === 'function') {
+                    window[setting.module][setting.function](setting.value);
+                }
+                else {
+                    window[setting.module][setting.function] = setting.value;
+                }
+            }
+        });
+    }
+}
+
+/** Adding marker legend in the upper left corner */
+projectUtils.addLegend = function (htmlContent) {
+    if (! htmlContent) {
+        if (document.getElementById("markerLegend")) {
+            document.getElementById("markerLegend").style.display= "none";
+        }
+        return;
+    }
+    var op = tmapp["object_prefix"];
+    if (document.getElementById("markerLegend") == undefined) {
+        var elt = document.createElement('div');
+        elt.className = "px-1 mx-1 viewer-layer"
+        elt.id = "markerLegend"
+        elt.style.zIndex = "13";
+        elt.style.left = "10px";
+        elt.style.top = "10px";
+        elt.style.padding = "5px";
+        elt.style.overflowY = "auto";
+        elt.style.maxHeight = "Calc(100vh - 245px)";
+        tmapp[tmapp["object_prefix"] + "_viewer"].addControl(elt,{anchor: OpenSeadragon.ControlAnchor.TOP_LEFT});
+    }
+    elt = document.getElementById("markerLegend");
+    elt.style.display="block";
+    elt.innerHTML = htmlContent;
 }
\ No newline at end of file
