@@ -153,6 +153,45 @@ class ImageConverter:
                 time.sleep(0.02)
         return self.outputImage
 
+    def convertToDZI(self):
+        if not os.path.isfile(self.outputImage):
+
+            def convertThread():
+                try:
+                    imgVips = pyvips.Image.new_from_file(self.inputImage)
+                    minVal = imgVips.percent(0.5)
+                    maxVal = imgVips.percent(99.5)
+                    if minVal == maxVal:
+                        minVal = 0
+                        maxVal = 255
+                    if (imgVips.percent(0.01) < 0 or imgVips.percent(99.99) > 255):
+                        imgVips = (255.0 * (imgVips - minVal)) / (maxVal - minVal)
+                        imgVips = (imgVips < 0).ifthenelse(0, imgVips)
+                        imgVips = (imgVips > 255).ifthenelse(255, imgVips)
+                        imgVips = imgVips.scaleimage()
+                    imgVips.dzsave(
+                        os.path.basename(self.outputImage),
+                        dirname=os.path.dirname(self.outputImage),
+                        suffix='.jpg',
+                        background=0,
+                        depth='onepixel',
+                        overlap=0,
+                        tile_size=256
+                    )
+                    
+                except:
+                    logging.error("Impossible to convert image using VIPS:")
+                    import traceback
+
+                    logging.error(traceback.format_exc())
+                self.convertDone = True
+
+            self.convertDone = False
+            threading.Thread(target=convertThread, daemon=True).start()
+            while not self.convertDone:
+                time.sleep(0.02)
+        return self.outputImage
+
 
 class _SlideCache(object):
     def __init__(self, cache_size, dz_opts):
@@ -241,7 +280,7 @@ def _setup():
 @app.errorhandler(404)
 def page_not_found(e):
     # note that we set the 404 status explicitly
-    return render_template("tissuumaps.html", isStandalone=app.config["isStandalone"], message="Impossible to load this file")
+    return render_template("tissuumaps.html", isStandalone=app.config["isStandalone"], message="Impossible to load this file", readOnly=app.config["READ_ONLY"])
 
 
 def _get_slide(path, originalPath=None):
@@ -278,7 +317,7 @@ def _get_slide(path, originalPath=None):
 @app.route("/")
 @requires_auth
 def index():
-    return render_template("tissuumaps.html", isStandalone=app.config["isStandalone"])
+    return render_template("tissuumaps.html", isStandalone=app.config["isStandalone"], readOnly=app.config["READ_ONLY"])
 
 @app.route("/web/<path:path>")
 @requires_auth
@@ -298,7 +337,6 @@ def slide(filename):
     path = os.path.abspath(os.path.join(app.basedir, path, filename))
     #slide = _get_slide(path)
     slide_url = os.path.basename(path)+".dzi"#url_for("dzi", path=path)
-    
     jsonProject={
         "layers": [
             {
@@ -311,7 +349,8 @@ def slide(filename):
         "tissuumaps.html",
         plugins=app.config["PLUGINS"],
         jsonProject=jsonProject,
-        isStandalone=app.config["isStandalone"]
+        isStandalone=app.config["isStandalone"],
+        readOnly=app.config["READ_ONLY"]
         )
 
 @app.route("/ping")
@@ -339,7 +378,8 @@ def tmapFile(filename):
     if not path:
         path = "./"
     jsonFilename = os.path.abspath(os.path.join(app.basedir, path, filename) + ".tmap")
-    if request.method == "POST":
+
+    if request.method == "POST" and not app.config["READ_ONLY"]:
         state = request.get_json(silent=False)
         with open(jsonFilename, "w") as jsonFile:
             json.dump(state, jsonFile, indent=4, sort_keys=True)
@@ -365,7 +405,8 @@ def tmapFile(filename):
             "tissuumaps.html",
             plugins=plugins,
             jsonProject=state,
-            isStandalone=app.config["isStandalone"]
+            isStandalone=app.config["isStandalone"],
+            readOnly=app.config["READ_ONLY"]
         )
 
 
